# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['shallow_backup']

package_data = \
{'': ['*']}

install_requires = \
['click>=7.0,<8.0',
 'colorama>=0.4.1,<0.5.0',
 'gitpython>=3.0,<4.0',
 'inquirer>=2.6,<3.0']

entry_points = \
{'console_scripts': ['shallow-backup = shallow_backup.__main__:cli']}

setup_kwargs = {
    'name': 'shallow-backup',
    'version': '2.9a0',
    'description': 'Easily create lightweight backups of installed packages, dotfiles, and more.',
    'long_description': "# shallow-backup\n\n[![Downloads](http://pepy.tech/badge/shallow-backup)](http://pepy.tech/count/shallow-backup)\n[![Build Status](https://travis-ci.com/alichtman/shallow-backup.svg?branch=master)](https://travis-ci.com/alichtman/shallow-backup)\n[![Codacy Badge](https://api.codacy.com/project/badge/Grade/1719da4d7df5455d8dbb4340c428f851)](https://www.codacy.com/app/alichtman/shallow-backup?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=alichtman/shallow-backup&amp;utm_campaign=Badge_Grade)\n<!-- [![Coverage Status](https://coveralls.io/repos/github/alichtman/shallow-backup/badge.svg?branch=master)](https://coveralls.io/github/alichtman/shallow-backup?branch=master) -->\n\n`shallow-backup` lets you easily create lightweight backups of installed packages, applications, fonts and dotfiles, and automatically push them to a remote Git repository.\n\n![Shallow Backup GIF Demo](img/shallow-backup-demo.gif)\n\nContents\n========\n\n * [Installation](#installation)\n * [Usage](#usage)\n * [Git Integration](#git-integration)\n * [What can I back up?](#what-can-i-back-up)\n * [Backup Customization](#backup-customization)\n * [Output Structure](#output-structure)\n * [Inspiration](#inspiration)\n * [Want to contribute?](#want-to-contribute)\n\n### Installation\n---\n\n1. Install with [`pip3`](https://pypi.org/project/shallow-backup/)\n    + `$ pip3 install shallow-backup`\n    + `$ shallow-backup`\n\n2. Download the `shallow-backup` binary from Releases tab.\n\n### Usage\n---\n\nTo start the interactive program, simply run `$ shallow-backup`.\n\n`shallow-backup` was built with scripting in mind. Every feature that's supported in the interactive program is supported with command line args.\n\n```shell\nUsage: shallow-backup [OPTIONS]\n\n  Easily back up installed packages, dotfiles, and more.\n  You can edit which files are backed up in ~/.shallow-backup.\n\n  Written by Aaron Lichtman (@alichtman).\n\nOptions:\n  -all                     Full back up.\n  -configs                 Back up app config files.\n  -delete_config           Delete config file.\n  -destroy_backup          Delete backup directory.\n  -dotfiles                Back up dotfiles.\n  -fonts                   Back up installed fonts.\n  --new_path TEXT          Input a new back up directory path.\n  -no_splash               Don't display splash screen.\n  -old_path                Skip setting new back up directory path prompt.\n  -packages                Back up package libraries.\n  -reinstall_all           Full reinstallation.\n  -reinstall_configs       Reinstall configs.\n  -reinstall_dots          Reinstall dotfiles and dotfolders.\n  -reinstall_fonts         Reinstall fonts.\n  -reinstall_packages      Reinstall packages.\n  --remote TEXT            Set remote URL for the git repo.\n  -separate_dotfiles_repo  Use if you are trying to maintain a separate\n                           dotfiles repo and running into issue #229.\n  -show                    Display config file.\n  -v, --version            Display version and author info.\n  -help, -h, --help        Show this message and exit.\n```\n\n### Git Integration\n---\n\n**A Word of Caution**\n\nThis backup tool is git-integrated, meaning that you can easily store your backups remotely (on GitHub, for example.) Dotfiles and configuration files may contain sensitive information like API keys and ssh keys, and you don't want to make those public. To make sure no sensitive files are uploaded accidentally, `shallow-backup` creates a `.gitignore` file if it can't find one in the directory. It excludes `.ssh/` and `.pypirc` by default. It's safe to remove these restrictions if you're pushing to a remote private repository, or you're only backing up locally. To do this, you should clear the `.gitignore` file without deleting it.\n\n_If you choose to back up to a public repository, look at every file you're backing up to make sure you want it to be public._\n\n**What if I'd like to maintain a separate repo for my dotfiles?**\n\n`shallow-backup` makes this easy! After making your first backup, `cd` into the `dotfiles/` directory and run `$ git init`. Create a `.gitignore` and a new repo on your favorite version control platform. This repo will be maintained independently (manually) of the base `shallow-backup` repo. Note that you may need to use the `-separate_dotfiles_repo` flag to get this to work, and it may [break some other functionality of the tool](https://github.com/alichtman/shallow-backup/issues/229). It's ok for my use case, though.\n\n### What can I back up?\n---\n\nBy default, `shallow-backup` backs these up.\n\n1. `dotfiles` and `dotfolders`.\n    * `.bashrc`\n    * `.bash_profile`\n    * `.gitconfig`\n    * `.pypirc`\n    * `.shallow-backup`\n    * `.ssh/`\n    * `.vim/`\n    * `.zshrc`\n\n2. App Config Files\n    * Atom\n    * VSCode\n    * Sublime Text 2/3\n    * Terminal.app\n\n3. Installed Packages\n    * `apm`\n    * `brew` and `cask`\n    * `cargo`\n    * `gem`\n    * `pip`\n    * `pip3`\n    * `npm`\n    * `macports`\n    * `VSCode` Extensions\n    * `Sublime Text 2/3` Packages\n    * System Applications\n\n4. User installed `fonts`.\n\n### Backup Customization\n\nIf you'd like to modify which files are backed up, you have to edit the `~/.shallow-backup` file. There are two recommended ways of doing this.\n\n1. Select the appropriate option in the CLI and follow the prompts.\n2. Open the file in a text editor and make your changes.\n\n#### Output Structure\n---\n\n```shell\nbackup_dir/\n├── configs\n│\xa0\xa0 ├── plist\n│\xa0\xa0 │\xa0\xa0 └── com.apple.Terminal.plist\n│\xa0\xa0 ├── sublime_2\n│\xa0\xa0 │\xa0\xa0 └── ...\n│\xa0\xa0 └── sublime_3\n│\xa0\xa0     └── ...\n├── dotfiles\n│   ├── .bash_profile\n│   ├── .bashrc\n│   ├── .gitconfig\n│   ├── .pypirc\n│   ├── ...\n│   ├── .shallow-backup\n│\xa0\xa0 ├── .ssh/\n│\xa0\xa0 │\xa0\xa0 └── known_hosts\n│\xa0\xa0 ├── .vim/\n│   └── .zshrc\n├── fonts\n│\xa0\xa0 ├── AllerDisplay.ttf\n│\xa0\xa0 ├── Aller_Bd.ttf\n│\xa0\xa0 ├── Aller_BdIt.ttf\n│\xa0\xa0 ├── Aller_It.ttf\n│\xa0\xa0 ├── ...\n│\xa0\xa0 ├── Ubuntu Mono derivative Powerline Bold Italic.ttf\n│\xa0\xa0 ├── Ubuntu Mono derivative Powerline Bold.ttf\n│\xa0\xa0 ├── Ubuntu Mono derivative Powerline Italic.ttf\n│\xa0\xa0 └── Ubuntu Mono derivative Powerline.ttf\n└── packages\n    ├── apm_list.txt\n    ├── brew-cask_list.txt\n    ├── brew_list.txt\n    ├── cargo_list.txt\n    ├── gem_list.txt\n    ├── installed_apps_list.txt\n    ├── npm_list.txt\n    ├── macports_list.txt\n    ├── pip_list.txt\n    └── sublime3_list.txt\n```\n\n### Inspiration\n---\n\nI back up system images of my MacBook Pro to an external SSD multiple times every week, and it always takes way too long. I wanted to speed this up, so I took a look at what was actually being backed up. I saw that my `brew`, `npm`, and `pip` libraries took up a ton more space than I imagined.\n\n*And that's totally unnecessary.* When you back something up, you do it with the intention of being able to get back to that exact state at some point in the future. The minimum you need in order to recreate those package libraries later is just a list of the packages that are installed with each package manager. If you have these lists, restoring your system package installs is easy: `$ pip install -r pip_list.txt`, for example.\n\nI cut down my backup size by almost `10GB` by replacing my `pip`, `brew`, `brew cask` and `npm` libraries with simple text files. I also cut down the back up time significantly since many fewer files were being copied.\n\nOnce I'd built that functionality, I wanted to have a single backup utility for files and folders often used by developers, so I added the ability to backup `dotfiles` and `fonts`. (Note: Because just having a list of installed fonts or a list of dotfiles that exist isn't very useful, `shallow-backup` creates copies of all dotfiles and user installed fonts.)\n\n### Want to Contribute?\n---\n\nCheck out `CONTRIBUTING.md` and the `docs` directory.\n",
    'author': 'Aaron Lichtman',
    'author_email': 'aaronlichtman@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/alichtman/shallow-backup',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
